summaryrefslogtreecommitdiff
path: root/indra/llwebrtc/llwebrtc.h
diff options
context:
space:
mode:
Diffstat (limited to 'indra/llwebrtc/llwebrtc.h')
-rw-r--r--indra/llwebrtc/llwebrtc.h9
1 files changed, 6 insertions, 3 deletions
diff --git a/indra/llwebrtc/llwebrtc.h b/indra/llwebrtc/llwebrtc.h
index f84e998245..e7effdfbb8 100644
--- a/indra/llwebrtc/llwebrtc.h
+++ b/indra/llwebrtc/llwebrtc.h
@@ -56,11 +56,14 @@ class LLWebRTCVoiceDevice
{
public:
std::string display_name; // friendly value for the user
- std::string id; // internal value for selection
+ std::string id; // internal value for selection
+ bool current; // current device
- LLWebRTCVoiceDevice(const std::string &display_name, const std::string &id) :
+ LLWebRTCVoiceDevice(const std::string &display_name, const std::string &id, bool current) :
display_name(display_name),
- id(id) {};
+ id(id),
+ current(current)
+ {};
};
typedef std::vector<LLWebRTCVoiceDevice> LLWebRTCVoiceDeviceList;